#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.matekbd"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[1061]; const double alignment; void * const ptr;}  matekbd_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0310, 0000, 0000, 0000, 0000, 0000, 0000, 0050, 0006, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0005, 0000, 0000, 0000, 0005, 0000, 0000, 0000, 0057, 0077, 0346, 0220, 0005, 0000, 0000, 0000, 
  0310, 0000, 0000, 0000, 0014, 0000, 0114, 0000, 0324, 0000, 0000, 0000, 0330, 0000, 0000, 0000, 
  0113, 0120, 0220, 0013, 0002, 0000, 0000, 0000, 0330, 0000, 0000, 0000, 0004, 0000, 0114, 0000, 
  0334, 0000, 0000, 0000, 0340, 0000, 0000, 0000, 0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 
  0340, 0000, 0000, 0000, 0001, 0000, 0114, 0000, 0344, 0000, 0000, 0000, 0350, 0000, 0000, 0000, 
  0317, 0003, 0072, 0200, 0000, 0000, 0000, 0000, 0350, 0000, 0000, 0000, 0011, 0000, 0114, 0000, 
  0364, 0000, 0000, 0000, 0370, 0000, 0000, 0000, 0247, 0117, 0336, 0033, 0003, 0000, 0000, 0000, 
  0370, 0000, 0000, 0000, 0016, 0000, 0166, 0000, 0010, 0001, 0000, 0000, 0031, 0004, 0000, 0000, 
  0201, 0321, 0040, 0031, 0001, 0000, 0000, 0000, 0031, 0004, 0000, 0000, 0005, 0000, 0114, 0000, 
  0040, 0004, 0000, 0000, 0044, 0004, 0000, 0000, 0160, 0145, 0162, 0151, 0160, 0150, 0145, 0162, 
  0141, 0154, 0163, 0057, 0003, 0000, 0000, 0000, 0157, 0162, 0147, 0057, 0005, 0000, 0000, 0000, 
  0057, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0153, 0145, 0171, 0142, 0157, 0141, 0162, 0144, 
  0057, 0000, 0000, 0000, 0004, 0000, 0000, 0000, 0163, 0150, 0157, 0167, 0055, 0154, 0141, 0171, 
  0157, 0165, 0164, 0056, 0165, 0151, 0000, 0000, 0032, 0017, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0345, 0127, 0115, 0163, 0332, 0060, 0020, 0275, 0347, 0127, 0250, 0072, 0266, 0143, 
  0014, 0244, 0235, 0144, 0072, 0306, 0231, 0174, 0220, 0064, 0223, 0317, 0011, 0344, 0354, 0221, 
  0355, 0005, 0124, 0024, 0311, 0225, 0004, 0011, 0235, 0376, 0370, 0112, 0066, 0041, 0020, 0004, 
  0216, 0235, 0036, 0062, 0323, 0243, 0127, 0373, 0126, 0273, 0117, 0373, 0344, 0125, 0160, 0360, 
  0364, 0300, 0320, 0024, 0244, 0242, 0202, 0167, 0160, 0253, 0321, 0304, 0010, 0170, 0042, 0122, 
  0312, 0207, 0035, 0174, 0337, 0077, 0365, 0366, 0361, 0101, 0270, 0023, 0174, 0362, 0074, 0164, 
  0006, 0034, 0044, 0321, 0220, 0242, 0107, 0252, 0107, 0150, 0310, 0110, 0012, 0150, 0267, 0321, 
  0156, 0066, 0232, 0310, 0363, 0012, 0247, 0317, 0036, 0172, 0020, 0051, 0174, 0107, 0066, 0254, 
  0371, 0262, 0146, 0312, 0065, 0310, 0001, 0111, 0040, 0334, 0101, 0050, 0220, 0360, 0153, 0102, 
  0045, 0050, 0304, 0150, 0334, 0301, 0103, 0075, 0376, 0202, 0137, 0366, 0337, 0155, 0264, 0276, 
  0142, 0077, 0367, 0023, 0361, 0117, 0110, 0064, 0112, 0030, 0121, 0252, 0203, 0317, 0364, 0370, 
  0204, 0022, 0046, 0206, 0030, 0321, 0324, 0300, 0224, 0111, 0041, 0031, 0121, 0035, 0061, 0062, 
  0023, 0023, 0035, 0115, 0051, 0074, 0142, 0213, 0063, 0310, 0114, 0212, 0014, 0244, 0236, 0041, 
  0116, 0036, 0240, 0203, 0023, 0302, 0243, 0201, 0110, 0046, 0012, 0207, 0247, 0204, 0051, 0010, 
  0374, 0147, 0007, 0267, 0177, 0054, 0144, 0012, 0062, 0172, 0244, 0251, 0036, 0341, 0360, 0133, 
  0231, 0273, 0246, 0232, 0001, 0106, 0132, 0022, 0256, 0030, 0321, 0044, 0146, 0306, 0070, 0003, 
  0263, 0333, 0005, 0314, 0142, 0101, 0144, 0212, 0056, 0363, 0034, 0313, 0002, 0031, 0116, 0350, 
  0157, 0013, 0177, 0143, 0236, 0051, 0050, 0055, 0305, 0054, 0262, 0207, 0021, 0145, 0104, 0002, 
  0327, 0070, 0354, 0313, 0111, 0051, 0120, 0317, 0062, 0210, 0106, 0324, 0272, 0247, 0071, 0247, 
  0153, 0000, 0303, 0054, 0113, 0121, 0176, 0156, 0234, 0060, 0057, 0377, 0354, 0340, 0151, 0054, 
  0236, 0346, 0034, 0273, 0316, 0347, 0310, 0254, 0346, 0207, 0123, 0004, 0365, 0254, 0173, 0153, 
  0341, 0277, 0236, 0306, 0224, 0052, 0232, 0127, 0353, 0312, 0271, 0316, 0101, 0272, 0060, 0102, 
  0122, 0303, 0013, 0321, 0246, 0273, 0160, 0150, 0332, 0114, 0323, 0204, 0260, 0267, 0000, 0125, 
  0106, 0022, 0243, 0001, 0034, 0266, 0235, 0336, 0156, 0206, 0110, 0142, 0067, 0212, 0314, 0131, 
  0220, 0245, 0302, 0235, 0144, 0115, 0264, 0026, 0374, 0065, 0145, 0113, 0370, 0326, 0112, 0200, 
  0032, 0354, 0325, 0145, 0320, 0205, 0233, 0213, 0114, 0351, 0231, 0335, 0021, 0170, 0272, 0021, 
  0230, 0023, 0261, 0152, 0333, 0134, 0176, 0121, 0173, 0254, 0371, 0255, 0314, 0273, 0361, 0025, 
  0314, 0225, 0107, 0014, 0014, 0207, 0346, 0322, 0360, 0062, 0013, 0331, 0224, 0106, 0155, 0302, 
  0112, 0110, 0253, 0012, 0225, 0220, 0000, 0235, 0202, 0212, 0122, 0030, 0220, 0011, 0323, 0325, 
  0043, 0300, 0324, 0264, 0257, 0331, 0371, 0354, 0344, 0042, 0272, 0275, 0071, 0277, 0356, 0167, 
  0357, 0242, 0253, 0233, 0376, 0371, 0315, 0165, 0164, 0165, 0330, 0273, 0100, 0177, 0220, 0143, 
  0345, 0207, 0371, 0132, 0136, 0076, 0272, 0357, 0367, 0215, 0371, 0366, 0256, 0333, 0353, 0071, 
  0354, 0167, 0335, 0313, 0356, 0141, 0257, 0233, 0257, 0124, 0311, 0155, 0242, 0300, 0264, 0204, 
  0110, 0306, 0145, 0145, 0005, 0176, 0321, 0000, 0153, 0166, 0243, 0261, 0261, 0021, 0331, 0033, 
  0150, 0170, 0312, 0010, 0117, 0253, 0323, 0067, 0240, 0214, 0125, 0107, 0145, 0102, 0321, 0342, 
  0306, 0150, 0156, 0053, 0312, 0231, 0175, 0340, 0073, 0044, 0120, 0123, 0026, 0307, 0114, 0050, 
  0250, 0046, 0213, 0304, 0102, 0076, 0272, 0054, 0054, 0264, 0266, 0042, 0326, 0065, 0265, 0365, 
  0052, 0373, 0117, 0033, 0267, 0375, 0057, 0032, 0327, 0125, 0276, 0273, 0364, 0115, 0145, 0127, 
  0372, 0313, 0024, 0065, 0127, 0202, 0330, 0144, 0042, 0073, 0317, 0154, 0377, 0053, 0125, 0325, 
  0267, 0203, 0242, 0065, 0172, 0326, 0065, 0275, 0145, 0044, 0312, 0044, 0330, 0011, 0065, 0132, 
  0031, 0241, 0076, 0300, 0217, 0275, 0144, 0326, 0175, 0367, 0124, 0265, 0165, 0262, 0152, 0355, 
  0127, 0034, 0043, 0062, 0146, 0036, 0021, 0043, 0301, 0114, 0312, 0176, 0375, 0133, 0267, 0122, 
  0224, 0367, 0113, 0240, 0312, 0061, 0226, 0253, 0176, 0163, 0053, 0267, 0352, 0266, 0362, 0152, 
  0211, 0053, 0213, 0101, 0061, 0220, 0172, 0246, 0077, 0206, 0240, 0325, 0002, 0261, 0142, 0106, 
  0346, 0341, 0222, 0011, 0256, 0114, 0066, 0155, 0034, 0076, 0117, 0163, 0201, 0277, 0342, 0124, 
  0012, 0365, 0366, 0162, 0354, 0161, 0361, 0377, 0162, 0140, 0137, 0031, 0347, 0311, 0004, 0371, 
  0114, 0272, 0210, 0236, 0113, 0157, 0116, 0315, 0342, 0215, 0350, 0025, 0343, 0253, 0227, 0277, 
  0021, 0375, 0347, 0150, 0013, 0340, 0113, 0375, 0201, 0277, 0364, 0124, 0375, 0013, 0206, 0147, 
  0201, 0074, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 
  0000, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[1061]; const double alignment; void * const ptr;}  matekbd_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\310\000\000\000\000\000\000\050\006\000\000\000"
  "\000\000\000\000\000\000\000\000\002\000\000\000\003\000\000\000"
  "\005\000\000\000\005\000\000\000\057\077\346\220\005\000\000\000"
  "\310\000\000\000\014\000\114\000\324\000\000\000\330\000\000\000"
  "\113\120\220\013\002\000\000\000\330\000\000\000\004\000\114\000"
  "\334\000\000\000\340\000\000\000\324\265\002\000\377\377\377\377"
  "\340\000\000\000\001\000\114\000\344\000\000\000\350\000\000\000"
  "\317\003\072\200\000\000\000\000\350\000\000\000\011\000\114\000"
  "\364\000\000\000\370\000\000\000\247\117\336\033\003\000\000\000"
  "\370\000\000\000\016\000\166\000\010\001\000\000\031\004\000\000"
  "\201\321\040\031\001\000\000\000\031\004\000\000\005\000\114\000"
  "\040\004\000\000\044\004\000\000\160\145\162\151\160\150\145\162"
  "\141\154\163\057\003\000\000\000\157\162\147\057\005\000\000\000"
  "\057\000\000\000\001\000\000\000\153\145\171\142\157\141\162\144"
  "\057\000\000\000\004\000\000\000\163\150\157\167\055\154\141\171"
  "\157\165\164\056\165\151\000\000\032\017\000\000\001\000\000\000"
  "\170\332\345\127\115\163\332\060\020\275\347\127\250\072\266\143"
  "\014\244\235\144\072\306\231\174\220\064\223\317\011\344\354\221"
  "\355\005\124\024\311\225\004\011\235\376\370\112\066\041\020\004"
  "\216\235\036\062\323\243\127\373\126\273\117\373\344\125\160\360"
  "\364\300\320\024\244\242\202\167\160\253\321\304\010\170\042\122"
  "\312\207\035\174\337\077\365\366\361\101\270\023\174\362\074\164"
  "\006\034\044\321\220\242\107\252\107\150\310\110\012\150\267\321"
  "\156\066\232\310\363\012\247\317\036\172\020\051\174\107\066\254"
  "\371\262\146\312\065\310\001\111\040\334\101\050\220\360\153\102"
  "\045\050\304\150\334\301\103\075\376\202\137\366\337\155\264\276"
  "\142\077\367\023\361\117\110\064\112\030\121\252\203\317\364\370"
  "\204\022\046\206\030\321\324\300\224\111\041\031\121\035\061\062"
  "\023\023\035\115\051\074\142\213\063\310\114\212\014\244\236\041"
  "\116\036\240\203\023\302\243\201\110\046\012\207\247\204\051\010"
  "\374\147\007\267\177\054\144\012\062\172\244\251\036\341\360\133"
  "\231\273\246\232\001\106\132\022\256\030\321\044\146\306\070\003"
  "\263\333\005\314\142\101\144\212\056\363\034\313\002\031\116\350"
  "\157\013\177\143\236\051\050\055\305\054\262\207\021\145\104\002"
  "\327\070\354\313\111\051\120\317\062\210\106\324\272\247\071\247"
  "\153\000\303\054\113\121\176\156\234\060\057\377\354\340\151\054"
  "\236\346\034\273\316\347\310\254\346\207\123\004\365\254\173\153"
  "\341\277\236\306\224\052\232\127\353\312\271\316\101\272\060\102"
  "\122\303\013\321\246\273\160\150\332\114\323\204\260\267\000\125"
  "\106\022\243\001\034\266\235\336\156\206\110\142\067\212\314\131"
  "\220\245\302\235\144\115\264\026\374\065\145\113\370\326\112\200"
  "\032\354\325\145\320\205\233\213\114\351\231\335\021\170\272\021"
  "\230\023\261\152\333\134\176\121\173\254\371\255\314\273\361\025"
  "\314\225\107\014\014\207\346\322\360\062\013\331\224\106\155\302"
  "\112\110\253\012\225\220\000\235\202\212\122\030\220\011\323\325"
  "\043\300\324\264\257\331\371\354\344\042\272\275\071\277\356\167"
  "\357\242\253\233\376\371\315\165\164\165\330\273\100\177\220\143"
  "\345\207\371\132\136\076\272\357\367\215\371\366\256\333\353\071"
  "\354\167\335\313\356\141\257\233\257\124\311\155\242\300\264\204"
  "\110\306\145\145\005\176\321\000\153\166\243\261\261\021\331\033"
  "\150\170\312\010\117\253\323\067\240\214\125\107\145\102\321\342"
  "\306\150\156\053\312\231\175\340\073\044\120\123\026\307\114\050"
  "\250\046\213\304\102\076\272\054\054\264\266\042\326\065\265\365"
  "\052\373\117\033\267\375\057\032\327\125\276\273\364\115\145\127"
  "\372\313\024\065\127\202\330\144\042\073\317\154\377\053\125\325"
  "\267\203\242\065\172\326\065\275\145\044\312\044\330\011\065\132"
  "\031\241\076\300\217\275\144\326\175\367\124\265\165\262\152\355"
  "\127\034\043\062\146\036\021\043\301\114\312\176\375\133\267\122"
  "\224\367\113\240\312\061\226\253\176\163\053\267\352\266\362\152"
  "\211\053\213\101\061\220\172\246\077\206\240\325\002\261\142\106"
  "\346\341\222\011\256\114\066\155\034\076\117\163\201\277\342\124"
  "\012\365\366\162\354\161\361\377\162\140\137\031\347\311\004\371"
  "\114\272\210\236\113\157\116\315\342\215\350\025\343\253\227\277"
  "\021\375\347\150\013\340\113\375\201\277\364\124\375\013\206\147"
  "\201\074\000\050\165\165\141\171\051\155\141\164\145\057\000\000"
  "\000\000\000\000" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { matekbd_resource_data.data, sizeof (matekbd_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *matekbd_get_resource (void);
GResource *matekbd_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
